==> v0.7.5.tar.gz: anilist-api-wrapper/src/queries/Staff.ts <==
import {
  StaffCharacterMediaArgs,
  StaffCharactersArgs,
  StaffStaffMediaArgs,
} from "../types/generated/graphql.ts"
import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { FuzzyDate, PageInfo } from "../anilist.ts"
import { User } from "./User.ts"
import { CharacterConnection } from "./Character.ts"
import { MediaConnection } from "./Media.ts"

export const StaffRoleType = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The voice actors of the character */
  withVoiceActor(fn: Fn<typeof Staff>) {
    query[0] = query[0].set({ subField: "voiceActor", level, hasSubField: true })
    let tmpQuery
    fn(Staff({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Notes regarding the VA's role for the character */
  withRoleNotes() {
    query[0] = query[0].set({ subField: "roleNotes", level })
    return this
  },
  /** Used for grouping roles where multiple dubs exist for the same language. Either dubbing company name or language variant. */
  withDubGroup() {
    query[0] = query[0].set({ subField: "dubGroup", level })
    return this
  },
})

const StaffEdge = ({ query, level }: Fields<UpdateOperation>) => ({
  withNode(fn: Fn<typeof Staff>) {
    query[0] = query[0].set({ subField: "node", level, hasSubField: true })
    let tmpQuery
    fn(Staff({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The id of the connection */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The role of the staff member in the production of the media */
  withRole() {
    query[0] = query[0].set({ subField: "role", level })
    return this
  },
  /** The order the staff should be displayed from the users favourites */
  withFavouriteOrder() {
    query[0] = query[0].set({ subField: "favouriteOrder", level })
    return this
  },
})

export const StaffConnection = ({ query, level }: Fields<UpdateOperation>) => ({
  withEdges(fn: Fn<typeof StaffEdge>) {
    query[0] = query[0].set({ subField: "edges", level, hasSubField: true })
    let tmpQuery
    fn(StaffEdge({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  withNodes(fn: Fn<typeof Staff>) {
    query[0] = query[0].set({ subField: "nodes", level, hasSubField: true })
    let tmpQuery
    fn(Staff({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The pagination information */
  withPageInfo(fn: Fn<typeof PageInfo>) {
    query[0] = query[0].set({ subField: "pageInfo", level, hasSubField: true })
    let tmpQuery
    fn(PageInfo({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

const StaffName = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The person's given name */
  withFirst() {
    query[0] = query[0].set({ subField: "first", level })
    return this
  },
  /** The person's middle name */
  withMiddle() {
    query[0] = query[0].set({ subField: "middle", level })
    return this
  },
  /** The person's surname */
  withLast() {
    query[0] = query[0].set({ subField: "last", level })
    return this
  },
  /** The person's first and last name */
  withFull() {
    query[0] = query[0].set({ subField: "full", level })
    return this
  },
  /** The person's full name in their native language */
  withNative() {
    query[0] = query[0].set({ subField: "native", level })
    return this
  },
  /** Other names the staff member might be referred to as (pen names) */
  withAlternative() {
    query[0] = query[0].set({ subField: "alternative", level })
    return this
  },
  /** The currently authenticated users preferred name language. Default romaji for non-authenticated */
  withUserPreferred() {
    query[0] = query[0].set({ subField: "userPreferred", level })
    return this
  },
})

const StaffImage = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The person's image of media at its largest size */
  withLarge() {
    query[0] = query[0].set({ subField: "large", level })
    return this
  },
  /** The person's image of media at medium size */
  withMedium() {
    query[0] = query[0].set({ subField: "medium", level })
    return this
  },
})

export const Staff = ({ query, level }: Fields<UpdateOperation>) => ({
  /**   The id of the staff member */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The names of the staff member */
  withName(fn: Fn<typeof StaffName>) {
    query[0] = query[0].set({ subField: "name", level, hasSubField: true })
    let tmpQuery
    fn(StaffName({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The primary language of the staff member. Current values: Japanese, English, Korean, Italian, Spanish, Portuguese, French, German, Hebrew, Hungarian, Chinese, Arabic, Filipino, Catalan, Finnish, Turkish, Dutch, Swedish, Thai, Tagalog, Malaysian, Indonesian, Vietnamese, Nepali, Hindi, Urdu */
  withLanguageV2() {
    query[0] = query[0].set({ subField: "languageV2", level })
    return this
  },
  /** The staff images */
  withImage(fn: Fn<typeof StaffImage>) {
    query[0] = query[0].set({ subField: "image", level, hasSubField: true })
    let tmpQuery
    fn(StaffImage({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** A general description of the staff member */
  withDescription(args?: { asHtml: boolean }) {
    query[0] = query[0].set({ subField: "description", level, variables: args })
    return this
  },
  /** The person's primary occupations */
  withPrimaryOccupations() {
    query[0] = query[0].set({ subField: "primaryOccupations", level })
    return this
  },
  /** The staff's gender. Usually Male, Female, or Non-binary but can be any string. */
  withGender() {
    query[0] = query[0].set({ subField: "gender", level })
    return this
  },
  withDateOfBirth(fn: Fn<typeof FuzzyDate>) {
    query[0] = query[0].set({ subField: "dateOfBirth", level, hasSubField: true })
    let tmpQuery
    fn(FuzzyDate({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  withDateOfDeath(fn: Fn<typeof FuzzyDate>) {
    query[0] = query[0].set({ subField: "dateOfDeath", level, hasSubField: true })
    let tmpQuery
    fn(FuzzyDate({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The person's age in years */
  withAge() {
    query[0] = query[0].set({ subField: "age", level })
    return this
  },
  /** [startYear, endYear] (If the 2nd value is not present staff is still active) */
  withYearsActive() {
    query[0] = query[0].set({ subField: "yearsActive", level })
    return this
  },
  /** The persons birthplace or hometown */
  withHomeTown() {
    query[0] = query[0].set({ subField: "homeTown", level })
    return this
  },
  /** The persons blood type */
  withBloodType() {
    query[0] = query[0].set({ subField: "bloodType", level })
    return this
  },
  /** If the staff member is marked as favourite by the currently authenticated user */
  withIsFavourite() {
    query[0] = query[0].set({ subField: "isFavourite", level })
    return this
  },
  /** If the staff member is blocked from being added to favourites */
  withIsFavouriteBlocked() {
    query[0] = query[0].set({ subField: "isFavouriteBlocked", level })
    return this
  },
  /** The url for the staff page on the AniList website */
  withSiteUrl() {
    query[0] = query[0].set({ subField: "siteUrl", level })
    return this
  },
  /** Media where the staff member has a production role */
  withStaffMedia(args: StaffStaffMediaArgs | undefined, fn: Fn<typeof MediaConnection>) {
    query[0] = query[0].set({ subField: "staffMedia", level, variables: args, hasSubField: true })
    let tmpQuery
    fn(MediaConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Characters voiced by the actor */
  withCharacters(args: StaffCharactersArgs | undefined, fn: Fn<typeof CharacterConnection>) {
    query[0] = query[0].set({ subField: "characters", level, variables: args, hasSubField: true })
    let tmpQuery
    fn(CharacterConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Media the actor voiced characters in. (Same data as characters with media as node instead of characters) */
  withCharacterMedia(args: StaffCharacterMediaArgs | undefined, fn: Fn<typeof MediaConnection>) {
    query[0] = query[0].set({
      subField: "characterMedia",
      level,
      variables: args,
      hasSubField: true,
    })
    let tmpQuery
    fn(MediaConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Staff member that the submission is referencing */
  withStaff(fn: Fn<typeof Staff>) {
    query[0] = query[0].set({ subField: "staff", level, hasSubField: true })
    let tmpQuery
    fn(Staff({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Submitter for the submission */
  withSubmitter(fn: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "submitter", level, hasSubField: true })
    let tmpQuery
    fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Status of the submission */
  withSubmissionStatus() {
    query[0] = query[0].set({ subField: "submissionStatus", level })
    return this
  },
  /** Inner details of submission status */
  withSubmissionNotes() {
    query[0] = query[0].set({ subField: "submissionNotes", level })
    return this
  },
  /** The amount of user's who have favourited the staff member */
  withFavourites() {
    query[0] = query[0].set({ subField: "favourites", level })
    return this
  },
  /** Notes for site moderators */
  withModNotes() {
    query[0] = query[0].set({ subField: "modNotes", level })
    return this
  },
})

==> 0.8.tar.gz: anilist-api-wrapper/src/queries/Staff.ts <==
import {
  StaffCharacterMediaArgs,
  StaffCharactersArgs,
  StaffStaffMediaArgs,
} from "../types/generated/graphql.ts"
import { Fields, Fn, UpdateOperation } from "../types/Anilist.ts"
import { FuzzyDate } from "../anilist.ts"
import { PageInfo } from "./Page.ts"
import { User } from "./User.ts"
import { CharacterConnection } from "./Character.ts"
import { MediaConnection } from "./Media.ts"

export const StaffRoleType = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The voice actors of the character */
  withVoiceActor(fn: Fn<typeof Staff>) {
    query[0] = query[0].set({ subField: "voiceActor", level, hasSubField: true })
    let tmpQuery
    fn(Staff({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Notes regarding the VA's role for the character */
  withRoleNotes() {
    query[0] = query[0].set({ subField: "roleNotes", level })
    return this
  },
  /** Used for grouping roles where multiple dubs exist for the same language. Either dubbing company name or language variant. */
  withDubGroup() {
    query[0] = query[0].set({ subField: "dubGroup", level })
    return this
  },
})

const StaffEdge = ({ query, level }: Fields<UpdateOperation>) => ({
  withNode(fn: Fn<typeof Staff>) {
    query[0] = query[0].set({ subField: "node", level, hasSubField: true })
    let tmpQuery
    fn(Staff({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The id of the connection */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The role of the staff member in the production of the media */
  withRole() {
    query[0] = query[0].set({ subField: "role", level })
    return this
  },
  /** The order the staff should be displayed from the users favourites */
  withFavouriteOrder() {
    query[0] = query[0].set({ subField: "favouriteOrder", level })
    return this
  },
})

export const StaffConnection = ({ query, level }: Fields<UpdateOperation>) => ({
  withEdges(fn: Fn<typeof StaffEdge>) {
    query[0] = query[0].set({ subField: "edges", level, hasSubField: true })
    let tmpQuery
    fn(StaffEdge({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  withNodes(fn: Fn<typeof Staff>) {
    query[0] = query[0].set({ subField: "nodes", level, hasSubField: true })
    let tmpQuery
    fn(Staff({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The pagination information */
  withPageInfo(fn: Fn<typeof PageInfo>) {
    query[0] = query[0].set({ subField: "pageInfo", level, hasSubField: true })
    let tmpQuery
    fn(PageInfo({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
})

const StaffName = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The person's given name */
  withFirst() {
    query[0] = query[0].set({ subField: "first", level })
    return this
  },
  /** The person's middle name */
  withMiddle() {
    query[0] = query[0].set({ subField: "middle", level })
    return this
  },
  /** The person's surname */
  withLast() {
    query[0] = query[0].set({ subField: "last", level })
    return this
  },
  /** The person's first and last name */
  withFull() {
    query[0] = query[0].set({ subField: "full", level })
    return this
  },
  /** The person's full name in their native language */
  withNative() {
    query[0] = query[0].set({ subField: "native", level })
    return this
  },
  /** Other names the staff member might be referred to as (pen names) */
  withAlternative() {
    query[0] = query[0].set({ subField: "alternative", level })
    return this
  },
  /** The currently authenticated users preferred name language. Default romaji for non-authenticated */
  withUserPreferred() {
    query[0] = query[0].set({ subField: "userPreferred", level })
    return this
  },
})

const StaffImage = ({ query, level }: Fields<UpdateOperation>) => ({
  /** The person's image of media at its largest size */
  withLarge() {
    query[0] = query[0].set({ subField: "large", level })
    return this
  },
  /** The person's image of media at medium size */
  withMedium() {
    query[0] = query[0].set({ subField: "medium", level })
    return this
  },
})

export const Staff = ({ query, level }: Fields<UpdateOperation>) => ({
  /**   The id of the staff member */
  withId() {
    query[0] = query[0].set({ subField: "id", level })
    return this
  },
  /** The names of the staff member */
  withName(fn: Fn<typeof StaffName>) {
    query[0] = query[0].set({ subField: "name", level, hasSubField: true })
    let tmpQuery
    fn(StaffName({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The primary language of the staff member. Current values: Japanese, English, Korean, Italian, Spanish, Portuguese, French, German, Hebrew, Hungarian, Chinese, Arabic, Filipino, Catalan, Finnish, Turkish, Dutch, Swedish, Thai, Tagalog, Malaysian, Indonesian, Vietnamese, Nepali, Hindi, Urdu */
  withLanguageV2() {
    query[0] = query[0].set({ subField: "languageV2", level })
    return this
  },
  /** The staff images */
  withImage(fn: Fn<typeof StaffImage>) {
    query[0] = query[0].set({ subField: "image", level, hasSubField: true })
    let tmpQuery
    fn(StaffImage({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** A general description of the staff member */
  withDescription(args?: { asHtml: boolean }) {
    query[0] = query[0].set({ subField: "description", level, variables: args })
    return this
  },
  /** The person's primary occupations */
  withPrimaryOccupations() {
    query[0] = query[0].set({ subField: "primaryOccupations", level })
    return this
  },
  /** The staff's gender. Usually Male, Female, or Non-binary but can be any string. */
  withGender() {
    query[0] = query[0].set({ subField: "gender", level })
    return this
  },
  withDateOfBirth(fn: Fn<typeof FuzzyDate>) {
    query[0] = query[0].set({ subField: "dateOfBirth", level, hasSubField: true })
    let tmpQuery
    fn(FuzzyDate({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  withDateOfDeath(fn: Fn<typeof FuzzyDate>) {
    query[0] = query[0].set({ subField: "dateOfDeath", level, hasSubField: true })
    let tmpQuery
    fn(FuzzyDate({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** The person's age in years */
  withAge() {
    query[0] = query[0].set({ subField: "age", level })
    return this
  },
  /** [startYear, endYear] (If the 2nd value is not present staff is still active) */
  withYearsActive() {
    query[0] = query[0].set({ subField: "yearsActive", level })
    return this
  },
  /** The persons birthplace or hometown */
  withHomeTown() {
    query[0] = query[0].set({ subField: "homeTown", level })
    return this
  },
  /** The persons blood type */
  withBloodType() {
    query[0] = query[0].set({ subField: "bloodType", level })
    return this
  },
  /** If the staff member is marked as favourite by the currently authenticated user */
  withIsFavourite() {
    query[0] = query[0].set({ subField: "isFavourite", level })
    return this
  },
  /** If the staff member is blocked from being added to favourites */
  withIsFavouriteBlocked() {
    query[0] = query[0].set({ subField: "isFavouriteBlocked", level })
    return this
  },
  /** The url for the staff page on the AniList website */
  withSiteUrl() {
    query[0] = query[0].set({ subField: "siteUrl", level })
    return this
  },
  /** Media where the staff member has a production role */
  withStaffMedia(args: StaffStaffMediaArgs | undefined, fn: Fn<typeof MediaConnection>) {
    query[0] = query[0].set({ subField: "staffMedia", level, variables: args, hasSubField: true })
    let tmpQuery
    fn(MediaConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Characters voiced by the actor */
  withCharacters(args: StaffCharactersArgs | undefined, fn: Fn<typeof CharacterConnection>) {
    query[0] = query[0].set({ subField: "characters", level, variables: args, hasSubField: true })
    let tmpQuery
    fn(CharacterConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Media the actor voiced characters in. (Same data as characters with media as node instead of characters) */
  withCharacterMedia(args: StaffCharacterMediaArgs | undefined, fn: Fn<typeof MediaConnection>) {
    query[0] = query[0].set({
      subField: "characterMedia",
      level,
      variables: args,
      hasSubField: true,
    })
    let tmpQuery
    fn(MediaConnection({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Staff member that the submission is referencing */
  withStaff(fn: Fn<typeof Staff>) {
    query[0] = query[0].set({ subField: "staff", level, hasSubField: true })
    let tmpQuery
    fn(Staff({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Submitter for the submission */
  withSubmitter(fn: Fn<typeof User>) {
    query[0] = query[0].set({ subField: "submitter", level, hasSubField: true })
    let tmpQuery
    fn(User({ query: tmpQuery = [query[0]], level: level + 1 }))
    query[0] = tmpQuery[0]
    return this
  },
  /** Status of the submission */
  withSubmissionStatus() {
    query[0] = query[0].set({ subField: "submissionStatus", level })
    return this
  },
  /** Inner details of submission status */
  withSubmissionNotes() {
    query[0] = query[0].set({ subField: "submissionNotes", level })
    return this
  },
  /** The amount of user's who have favourited the staff member */
  withFavourites() {
    query[0] = query[0].set({ subField: "favourites", level })
    return this
  },
  /** Notes for site moderators */
  withModNotes() {
    query[0] = query[0].set({ subField: "modNotes", level })
    return this
  },
})
